@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Aug 2002
 ;;;;
-;;;; $Id: stdsite.lisp 10300 2005-01-29 02:14:07Z kevin $
+;;;; $Id: stdsite.lisp 11296 2006-11-07 18:27:21Z kevin $
 ;;;;
 ;;;; This file, part of LML2, is Copyright (c) 2000-2003 by Kevin Rosenberg.
 ;;;; Rights of modification and redistribution are in the LICENSE file.
@@ -22,6 +22,9 @@
 ;;;  banner.lml_
 ;;;  content.lml_
 ;;;  footer.lml_
+;;; These files are optional
+;;;  final.lml_
+;;;  rightcol.lml_
 
 (in-package #:lml2)
 
@@ -58,7 +61,10 @@
 	 (lml-load "contents.lml_"))
 	((:td :valign "top")
 	 ,@body
-	 (std-footer ,file))))))))
+	 (std-footer ,file))
+        ((:td :valign "top")
+         (lml-load "rightcol.lml_" :optional t)))))
+     (lml-load "final.lml_" :optional t))))
   
 
 (defmacro print-std-page (file title format &body body)
